#[non_exhaustive]pub enum AssuredEncodeError {
Assurance(AssuranceError),
Protection(ProtectionError),
Encode(SecretEncodeError),
Cleanup(CleanupError),
}Expand description
Redacted assured encode failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Assurance(AssuranceError)
Token or context evidence is stale.
Protection(ProtectionError)
Allocation-specific protection is unavailable or stale.
Encode(SecretEncodeError)
Secret encoder rejected a public bound or internal state.
Cleanup(CleanupError)
Cleanup transferred the consumed allocation to quarantine or tombstone.