#[non_exhaustive]pub enum Atomicity {
Unchanged,
Rollback,
CommittedPrefix,
IrrevocableSink,
}Expand description
Destination mutation contract used by API and corpus metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unchanged
Destination bytes remain unchanged on every returned error.
Rollback
A rewindable destination is restored to its entry length or position.
CommittedPrefix
Exact reported prefixes remain committed.
IrrevocableSink
A third-party sink may have irreversible or unknowable side effects.
Implementations