#[non_exhaustive]pub enum ConstTransformError {
LengthOverflow,
Input(InputError),
OutputLengthMismatch {
required: usize,
actual: usize,
},
}Expand description
Error returned by an exact const transform.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthOverflow
The exact output length cannot be represented by usize.
Input(InputError)
The encoded input is malformed under the selected codec settings.
OutputLengthMismatch
The output array length is not the exact result length.