pub enum DecodeError {
InvalidInput,
InvalidLength,
InvalidByte {
index: usize,
byte: u8,
},
InvalidPadding {
index: usize,
},
InvalidLineWrap {
index: usize,
},
OutputTooSmall {
required: usize,
available: usize,
},
}Expand description
Decoding error.
Variants
InvalidInput
The encoded input is malformed, but the decoder intentionally does not disclose a more specific error class.
InvalidLength
The encoded input length is impossible for the selected padding policy.
InvalidByte
A byte is not valid for the selected alphabet.
InvalidPadding
Padding is missing, misplaced, or non-canonical.
InvalidLineWrap
Line wrapping is missing, misplaced, or uses the wrong line ending.
OutputTooSmall
The output buffer is too small.