DecodeErrorKind

Enum DecodeErrorKind 

#[non_exhaustive]
pub enum DecodeErrorKind { InvalidInput, InvalidLength, InvalidByte, InvalidPadding, InvalidLineWrap, OutputTooSmall, StagingTooSmall, }
Redacted decoding error class.

This type intentionally omits input-derived bytes and indexes so callers can log error classes without logging secret-adjacent input content.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidInput

The encoded input is malformed, but the decoder intentionally does not disclose a more specific error class.



InvalidLength

The encoded input length is impossible for the selected padding policy.



InvalidByte

A byte is not valid for the selected alphabet.



InvalidPadding

Padding is missing, misplaced, or non-canonical.



InvalidLineWrap

Line wrapping is missing, misplaced, or uses the wrong line ending.



OutputTooSmall

The output buffer is too small.



StagingTooSmall

The caller-provided constant-time staging buffer is too small.

Implementations

Source

impl DecodeErrorKind

pub const fn as_str(self) -> &'static str

Returns the stable lowercase identifier for this error class.