#[non_exhaustive]pub enum Failure {
Input(InputError),
PositionOverflow,
Backend(BackendFault),
ResourceLimit,
}Expand description
Absorbing transform failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Input(InputError)
Attacker-controlled or otherwise malformed ordinary input.
PositionOverflow
Absolute source position can no longer be represented by usize.
Backend(BackendFault)
Internal backend integrity failure.
ResourceLimit
A caller-declared input, output, allocation, or frame limit was exceeded.
Implementations