InPlaceError

Enum InPlaceError 

#[non_exhaustive]
pub enum InPlaceError { InputLengthExceedsBuffer { input_len: usize, buffer_len: usize, }, LengthOverflow, OutputTooSmall { required: usize, available: usize, }, StagingTooSmall { required: usize, available: usize, }, OverlappingBuffers, AddressRangeOverflow, SecretPolicyUnsupported, Input(InputError), PositionOverflow, InvalidSecretInput, Backend(BackendFault), }
Error returned by a finite-buffer in-place operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InputLengthExceedsBuffer

The caller-declared input prefix exceeds the complete buffer.

Fields

input_len: usize

Declared encoded or plaintext input bytes.

buffer_len: usize

Complete caller buffer bytes.



LengthOverflow

The encoded or staging capacity calculation overflowed usize.



OutputTooSmall

Reverse encoding needs more bytes than the complete caller buffer.

Fields

required: usize

Exact encoded output bytes.

available: usize

Complete caller buffer bytes.



StagingTooSmall

Secret decode staging cannot hold the fixed-work candidate output.

Fields

required: usize

Required private staging bytes.

available: usize

Available private staging bytes.



OverlappingBuffers

Caller-visible and private staging byte ranges overlap.



AddressRangeOverflow

A byte range end address cannot be represented by usize.



SecretPolicyUnsupported

The selected compatibility policy is not eligible for secret decode.



Input(InputError)

Strict ordinary validation rejected the encoded input.



PositionOverflow

Absolute ordinary source positions cannot be represented by usize.



InvalidSecretInput

Fixed-work secret validation rejected the encoded input opaquely.



Backend(BackendFault)

An internal backend integrity invariant failed.