InputError

Enum InputError 

#[non_exhaustive]
pub enum InputError { InvalidByte { index: usize, byte: u8, }, InvalidPadding { index: usize, }, NonCanonicalTrailingBits { index: usize, }, InvalidLength, TruncatedInput { index: usize, }, TrailingData { index: usize, }, InvalidLineWrap { index: usize, }, }
Detailed ordinary malformed-input diagnostic.

Debug is redacted. Display includes ordinary input diagnostics and must not be logged for secret-bearing input.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidByte

A byte is outside the selected alphabet.

Fields

index: usize

Original absolute source index.

byte: u8

Rejected byte.



InvalidPadding

Padding became invalid at this original absolute source index.

Fields

index: usize

Original absolute source index.



NonCanonicalTrailingBits

Unused trailing bits are non-zero.

Fields

index: usize

Original absolute source index of the final significant symbol.



InvalidLength

The encoded length cannot represent a complete value.



TruncatedInput

Finishing found an incomplete encoded quantum.

Fields

index: usize

Original absolute source index at end of input.



TrailingData

Input followed a terminal padded quantum.

Fields

index: usize

Original absolute source index of the first trailing byte.



InvalidLineWrap

Wrapped body layout is malformed.

Fields

index: usize

Original absolute source index where layout became invalid.

Implementations

Source

impl InputError

pub const fn kind(self) -> InputErrorKind

Returns a redacted, stable error class.