#[non_exhaustive]pub enum Status {
NeedInput,
OutputFull(OutputFull),
Complete,
}Expand description
Non-failing state reached after one transform call.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NeedInput
More input or an explicit finish call is required.
OutputFull(OutputFull)
Retry with at least the reported output capacity.
Complete
The transform completed successfully and accepts no more input.
Implementations