pub enum ValidatedAlphabetError {
InvalidLength {
actual: usize,
},
InvalidByte {
index: usize,
byte: u8,
},
PaddingByte {
index: usize,
},
DuplicateByte {
first: usize,
second: usize,
byte: u8,
},
}Expand description
Failure returned while constructing a ValidatedAlphabet.
Variants
InvalidLength
A byte slice did not contain exactly 64 bytes.
InvalidByte
An alphabet position contains a byte outside visible ASCII.
PaddingByte
An alphabet position contains the reserved padding byte =.
DuplicateByte
Two alphabet positions contain the same byte.