#[non_exhaustive]pub enum BackendHealthPosture {
ScalarFixed,
NeverRun,
Testing,
Healthy,
Quarantined,
SynchronizationUnavailable,
SecretPolicyFixed,
}Expand description
Current ordinary backend-health evidence.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ScalarFixed
Scalar execution has no accelerated implementation to self-test.
NeverRun
The selected candidate has not completed its known-answer test.
Testing
A thread is currently running the candidate’s known-answer test.
Healthy
The candidate passed its known-answer test.
Quarantined
The candidate failed an integrity check and is permanently disabled.
This target cannot provide the atomic health latch required for SIMD.
SecretPolicyFixed
The secret scalar boundary is fixed by policy rather than selected by ordinary SIMD dispatch.
Implementations