SecurityPosture

Enum SecurityPosture 

#[non_exhaustive]
pub enum SecurityPosture { ScalarOnly, SimdCandidateScalarActive, Accelerated, }
Security posture for the active runtime backend.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ScalarOnly

No accelerated backend is active.



SimdCandidateScalarActive

SIMD support may be detected, but execution still uses scalar.



Accelerated

A SIMD backend is active.

Implementations

Source

impl SecurityPosture

pub const fn as_str(self) -> &'static str

Returns the stable lowercase identifier for this security posture.

assert_eq!(
    base64_ng::runtime::SecurityPosture::ScalarOnly.as_str(),
    "scalar-only",
);