WipePosture

Enum WipePosture 

#[non_exhaustive]
pub enum WipePosture { HardwareFence, CompilerFenceOnly, }
Wipe-barrier posture for this build and target.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


HardwareFence

The target uses a native store-ordering hardware fence in addition to volatile writes and compiler fences.

This describes wipe-store ordering only. It is separate from CtGatePosture, which reports whether the constant-time result gate has a speculation barrier or only an ordering fence.



CompilerFenceOnly

The target uses volatile writes and compiler fences only.

Implementations

Source

impl WipePosture

pub const fn as_str(self) -> &'static str

Returns the stable lowercase identifier for this wipe posture.