BackendSnapshot

Struct BackendSnapshot 

pub struct BackendSnapshot {
Show 16 fields pub active: &'static str, pub accelerated_backend_active: bool, pub security_posture: &'static str, pub encode_backend: OperationBackendSnapshot, pub strict_decode_backend: OperationBackendSnapshot, pub secret_decode_backend: OperationBackendSnapshot, pub candidate: &'static str, pub candidate_detection_mode: &'static str, pub candidate_required_cpu_features: &'static [&'static str], pub simd_feature_enabled: bool, pub ordinary_acceleration_active: bool, pub unsafe_boundary_enforced: bool, pub wasm_artifact_posture: &'static str, pub wasm_runtime_posture: &'static str, pub wipe_posture: &'static str, pub ct_gate_posture: &'static str,
}
Compact structured backend snapshot for logging and policy evidence.

Fields

active: &'static str

Stable compatibility alias for the ordinary encode backend.

accelerated_backend_active: bool

Compatibility alias reporting whether ordinary encode is accelerated.

security_posture: &'static str

Stable compatibility posture for ordinary encode and its candidate.

encode_backend: OperationBackendSnapshot

Stable ordinary encode report.

strict_decode_backend: OperationBackendSnapshot

Stable ordinary strict-decode report.

secret_decode_backend: OperationBackendSnapshot

Stable secret decode report.

candidate: &'static str

Stable detected candidate identifier.

candidate_detection_mode: &'static str

Stable SIMD candidate detection-mode identifier.

candidate_required_cpu_features: &'static [&'static str]

CPU features required by the detected candidate.

simd_feature_enabled: bool

Whether the simd feature is enabled in this build.

ordinary_acceleration_active: bool

Whether either ordinary operation selects acceleration.

unsafe_boundary_enforced: bool

Whether this build keeps the high-assurance scalar unsafe boundary.

This is false for simd builds even while execution remains scalar-only, because those builds include additional private prototype boundaries.

wasm_artifact_posture: &'static str

Stable Wasm artifact posture identifier.

wasm_runtime_posture: &'static str

Stable Wasm host-runtime posture identifier.

wipe_posture: &'static str

Stable wipe-barrier posture identifier.

ct_gate_posture: &'static str

Stable constant-time result-gate barrier posture identifier.