#[non_exhaustive]pub enum SecretEncodeError {
InputTooLarge {
input_len: usize,
maximum_input_len: usize,
},
OutputFull {
required: usize,
available: usize,
},
OverlappingBuffers,
AddressRangeOverflow,
LengthOverflow,
AllocationFailed,
Failed,
Complete,
}Expand description
Error returned by a secret encoding frame.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputTooLarge
The public cumulative input length exceeds the declared frame limit.
Fields
OutputFull
Secret output storage cannot hold the declared maximum encoded result.
Fields
OverlappingBuffers
Secret input and output storage overlap.
AddressRangeOverflow
A byte-range end address cannot be represented by usize.
LengthOverflow
Encoded-length or source-position arithmetic overflowed.
AllocationFailed
A preallocated heap encoder could not reserve its complete storage.
Failed
The encoder previously failed and is absorbing.
Complete
The encoder has already completed successfully.