Bcrypt

Struct Bcrypt 

pub struct Bcrypt;
The bcrypt Base64 alphabet.

This alphabet is commonly used by bcrypt hash strings. It is provided as an alphabet/profile building block; base64-ng does not parse or verify full bcrypt password-hash records.