pub struct CodecBuilder { /* private fields */ }Expand description
Fallible no-allocation builder for an advanced ordinary runtime codec.
Implementations
Sourceimpl CodecBuilder
impl CodecBuilder
Sourcepub const fn new(alphabet: ValidatedAlphabet) -> Self
pub const fn new(alphabet: ValidatedAlphabet) -> Self
Starts with strict canonical padded policies and an owned alphabet.
Sourcepub const fn from_table(table: [u8; 64]) -> Result<Self, ValidatedAlphabetError>
pub const fn from_table(table: [u8; 64]) -> Result<Self, ValidatedAlphabetError>
Validates and owns an alphabet table before constructing the builder.
Sourcepub const fn from_slice(bytes: &[u8]) -> Result<Self, ValidatedAlphabetError>
pub const fn from_slice(bytes: &[u8]) -> Result<Self, ValidatedAlphabetError>
Copies and validates a runtime alphabet slice.
Sourcepub const fn encode_padding(self, policy: EncodePadding) -> Self
pub const fn encode_padding(self, policy: EncodePadding) -> Self
Sets whether encoding emits padding.
Sourcepub const fn decode_padding(self, policy: DecodePadding) -> Self
pub const fn decode_padding(self, policy: DecodePadding) -> Self
Sets the ordinary decode-padding policy.
Sourcepub const fn trailing_bits(self, policy: TrailingBits) -> Self
pub const fn trailing_bits(self, policy: TrailingBits) -> Self
Sets the ordinary trailing-bit canonicality policy.
Sourcepub const fn build(self) -> Result<Base64<RuntimeSpec>, CodecBuilderError>
pub const fn build(self) -> Result<Base64<RuntimeSpec>, CodecBuilderError>
Validates policy compatibility and constructs an owned runtime codec.