pub struct OutputFull { /* private fields */ }Expand description
Retry information when the current destination cannot make progress.
Implementations
Sourceimpl OutputFull
impl OutputFull
Sourcepub const fn minimum_output(self) -> NonZeroUsize
pub const fn minimum_output(self) -> NonZeroUsize
Returns the minimum destination bytes needed by the next retry.