pub trait ThreadMovableProvider: ProtectedMemoryProvider + ThreadMovable { }Expand description
Sealed proof that provider protection and teardown may move across threads.
This is implemented only for providers reviewed inside base64-ng.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".