#[non_exhaustive]pub enum BackendPolicy {
ScalarExecutionOnly,
SimdFeatureDisabled,
NoDetectedSimdCandidate,
HighAssuranceScalarOnly,
}Expand description
Deployment policy for runtime backend assertions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ScalarExecutionOnly
Require encode/decode execution to use the scalar backend.
SimdFeatureDisabled
Require the crate to be built without the simd feature.
NoDetectedSimdCandidate
Require no SIMD candidate to be visible to this build and target.
HighAssuranceScalarOnly
Require scalar execution, the simd feature disabled, no detected
SIMD candidate, and the unsafe boundary enforced.
Implementations