#[non_exhaustive]pub enum CandidateDetectionMode {
SimdFeatureDisabled,
RuntimeCpuFeatures,
CompileTimeTargetFeatures,
}Expand description
How SIMD backend candidates were detected for this build.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SimdFeatureDisabled
SIMD candidate detection is disabled because the simd feature is
not enabled.
RuntimeCpuFeatures
Candidate detection uses runtime CPU feature probing.
CompileTimeTargetFeatures
Candidate detection uses compile-time target features.
This mode does not prove that the deployment CPU has the reported feature; it only reflects how the binary was compiled.
Implementations