pub struct DecoderReader<R, A, const PAD: bool>where
A: Alphabet,{ /* private fields */ }Expand description
A streaming Base64 decoder for std::io::Read.
For padded engines, this reader stops at the terminal padded Base64 block and leaves later bytes unread in the wrapped reader. This preserves boundaries for callers that decode one Base64 payload from a larger stream.
Implementations
Sourceimpl<R, A, const PAD: bool> DecoderReader<R, A, PAD>where
A: Alphabet,
impl<R, A, const PAD: bool> DecoderReader<R, A, PAD>where
A: Alphabet,
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Consumes the decoder reader and returns the wrapped reader.