LineWrap

Struct LineWrap 

pub struct LineWrap {
    pub line_len: usize,
    pub line_ending: LineEnding,
}
Base64 line wrapping policy.

line_len is measured in encoded Base64 bytes, not source input bytes. Encoders insert line endings between lines and do not append a trailing line ending after the final line.

Fields

line_len: usize

Maximum encoded bytes per line.

line_ending: LineEnding

Line ending inserted between wrapped lines.

Implementations

Source

impl LineWrap

pub const MIME: Self

MIME-style wrapping: 76 columns with CRLF endings.

pub const PEM: Self

PEM-style wrapping: 64 columns with LF endings.

pub const PEM_CRLF: Self

PEM-style wrapping: 64 columns with CRLF endings.

pub const fn new(line_len: usize, line_ending: LineEnding) -> Self

Creates a wrapping policy.